==> guile-0.4.0-3.tar.gz: guile-0.4.0/libguile/strop.h <==
/* classes: h_files */

#ifndef STROPH
#define STROPH
/*	Copyright (C) 1995 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  
 */


#include "__scm.h"



#ifdef __STDC__
extern int scm_i_index (SCM * str, SCM chr, int pos, int pos2, char * why);
extern int scm_i_rindex (SCM * str, SCM chr, int pos, int pos2, char * why);
extern SCM scm_string_index (SCM str, SCM chr);
extern SCM scm_string_rindex (SCM str, SCM chr);
extern SCM scm_substring_move_left_x (SCM str1, SCM start1, SCM args);
extern SCM scm_substring_move_right_x (SCM str1, SCM start1, SCM args);
extern SCM scm_substring_fill_x (SCM str, SCM start, SCM args);
extern SCM scm_string_null_p (SCM str);
extern SCM scm_string_to_list (SCM str);
extern SCM scm_string_copy (SCM str);
extern SCM scm_string_fill_x (SCM str, SCM chr);
extern void scm_init_strop (void);

#else /* STDC */
extern int scm_i_index ();
extern int scm_i_rindex ();
extern SCM scm_string_index ();
extern SCM scm_string_rindex ();
extern SCM scm_substring_move_left_x ();
extern SCM scm_substring_move_right_x ();
extern SCM scm_substring_fill_x ();
extern SCM scm_string_null_p ();
extern SCM scm_string_to_list ();
extern SCM scm_string_copy ();
extern SCM scm_string_fill_x ();
extern void scm_init_strop ();

#endif /* STDC */







#endif  /* STROPH */

==> guile-1.0.tar.gz: guile-1.0/libguile/strop.h <==
/* classes: h_files */

#ifndef STROPH
#define STROPH
/*	Copyright (C) 1995,1996 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  
 */


#include "libguile/__scm.h"




extern int scm_i_index SCM_P ((SCM * str, SCM chr, SCM sub_start, SCM sub_end, int pos, int pos2, int pos3, int pos4, char * why));
extern int scm_i_rindex SCM_P ((SCM * str, SCM chr, SCM sub_start, SCM sub_end, int pos, int pos2, int pos3, int pos4, char * why));
extern SCM scm_string_index SCM_P ((SCM str, SCM chr, SCM frm, SCM to));
extern SCM scm_string_rindex SCM_P ((SCM str, SCM chr, SCM frm, SCM to));
extern SCM scm_substring_move_left_x SCM_P ((SCM str1, SCM start1, SCM args));
extern SCM scm_substring_move_right_x SCM_P ((SCM str1, SCM start1, SCM args));
extern SCM scm_substring_fill_x SCM_P ((SCM str, SCM start, SCM args));
extern SCM scm_string_null_p SCM_P ((SCM str));
extern SCM scm_string_to_list SCM_P ((SCM str));
extern SCM scm_string_copy SCM_P ((SCM str));
extern SCM scm_string_fill_x SCM_P ((SCM str, SCM chr));
extern void scm_init_strop SCM_P ((void));

#endif  /* STROPH */
